@@ -24,7 +24,9 @@
 
 #include <NetworkManagerQt/Manager>
 
+#include <KNotification>
 #include <QObject>
+#include <QPointer>
 
 class PortalMonitor : public QObject
 {
@@ -36,6 +38,9 @@ public:
 private Q_SLOTS:
     void connectivityChanged(NetworkManager::Connectivity connectivity);
     void checkConnectivity();
+
+private:
+    QPointer<KNotification> m_notification;
 };
 
 #endif // PLASMA_NM_PORTAL_MONITOR_H
