@@ -53,9 +53,9 @@
 #include <NetworkManagerQt/VpnSetting>
 #include <NetworkManagerQt/Utils>
 #include <NetworkManagerQt/WirelessSetting>
+#include <NetworkManagerQt/WirelessSecuritySetting>
 #include <NetworkManagerQt/WirelessDevice>
 
-#include <KIconLoader>
 #include <KLocalizedString>
 #include <KNotification>
 #include <KServiceTypeTrader>
@@ -145,6 +145,23 @@ NMVariantMapMap ConnectionEditorBase::setting() const
             if (securitySetting->keyMgmt() != NetworkManager::WirelessSecuritySetting::WirelessSecuritySetting::Unknown) {
                 wirelessSetting->setSecurity("802-11-wireless-security");
             }
+
+            if (securitySetting->keyMgmt() == NetworkManager::WirelessSecuritySetting::SAE &&
+                    wirelessSetting->mode() == NetworkManager::WirelessSetting::Adhoc) {
+                // Ad-Hoc settings as specified by the supplicant
+                // Proto
+                QList<NetworkManager::WirelessSecuritySetting::WpaProtocolVersion> protoVersions = securitySetting->proto();
+                protoVersions << NetworkManager::WirelessSecuritySetting::Rsn;
+                securitySetting->setProto(protoVersions);
+                // Pairwise
+                QList<NetworkManager::WirelessSecuritySetting::WpaEncryptionCapabilities> pairwiseEncrypts = securitySetting->pairwise();
+                pairwiseEncrypts << NetworkManager::WirelessSecuritySetting::Ccmp;
+                securitySetting->setPairwise(pairwiseEncrypts);
+                // Group
+                QList<NetworkManager::WirelessSecuritySetting::WpaEncryptionCapabilities> groupEncrypts = securitySetting->group();
+                groupEncrypts << NetworkManager::WirelessSecuritySetting::Ccmp;
+                securitySetting->setGroup(groupEncrypts);
+            }
         }
     }
     return connectionSettings->toMap();
@@ -465,7 +482,7 @@ void ConnectionEditorBase::replyFinished(QDBusPendingCallWatcher *watcher)
         notification->setComponentName("networkmanagement");
         notification->setTitle(i18n("Failed to get secrets for %1", watcher->property("connection").toString()));
         notification->setText(reply.error().message());
-        notification->setPixmap(QIcon::fromTheme("dialog-warning").pixmap(KIconLoader::SizeHuge));
+        notification->setIconName(QStringLiteral("dialog-warning"));
         notification->sendEvent();
     }
 
