@@ -90,17 +90,13 @@ Handler::Handler(QObject *parent)
         NetworkManager::ActiveConnection::Ptr hotspot = NetworkManager::findActiveConnection(Configuration::hotspotConnectionPath());
         if (!hotspot) {
             Configuration::setHotspotConnectionPath(QString());
-            Q_EMIT hotspotDisabled();
         }
     }
 
     m_hotspotSupported = checkHotspotSupported();
 
     if (NetworkManager::checkVersion(1, 16, 0)) {
-        connect(NetworkManager::notifier(), &NetworkManager::Notifier::primaryConnectionTypeChanged, [this] () {
-            m_hotspotSupported = checkHotspotSupported();
-            Q_EMIT hotspotSupportedChanged(m_hotspotSupported);
-        });
+        connect(NetworkManager::notifier(), &NetworkManager::Notifier::primaryConnectionTypeChanged, this, &Handler::primaryConnectionTypeChanged);
     }
 }
 
@@ -870,6 +866,13 @@ void Handler::hotspotCreated(QDBusPendingCallWatcher *watcher)
     }
 }
 
+void Handler::primaryConnectionTypeChanged(NetworkManager::ConnectionSettings::ConnectionType type)
+{
+    Q_UNUSED(type)
+    m_hotspotSupported = checkHotspotSupported();
+    Q_EMIT hotspotSupportedChanged(m_hotspotSupported);
+}
+
 #if WITH_MODEMMANAGER_SUPPORT
 void Handler::unlockRequiredChanged(MMModemLock modemLock)
 {
