@@ -199,6 +199,7 @@ CreatableConnectionsModel::CreatableConnectionsModel(QObject *parent)
                                                     NetworkManager::ConnectionSettings::Vlan,
                                                     QString(), QString(), true); // VpnType and SpecificType are empty
         m_list << connectionItem;
+
     }
 
     KService::List services = KServiceTypeTrader::self()->query("PlasmaNetworkManagement/VpnUiPlugin");
@@ -220,6 +221,16 @@ CreatableConnectionsModel::CreatableConnectionsModel(QObject *parent)
         m_list << connectionItem;
     }
 
+
+    // WireGuard changed from VPN plugin to primary device in version 1.16 of NetworkManager
+    if (NetworkManager::checkVersion(1, 16, 0)) {
+            connectionItem = new CreatableConnectionItem(i18n("WireGuard"), i18n("VPN connections"),
+                                                         i18n("WireGuard"), QStringLiteral("network-vpn"),
+                                                         NetworkManager::ConnectionSettings::WireGuard,
+                                                         QStringLiteral("WireGuard"), QString(), true); // VpnType and SpecificType are empty
+            m_list << connectionItem;
+    }
+
     // Placeholder for VPN import
     connectionItem = new CreatableConnectionItem(i18n("Import VPN connection..."), i18n("Other"),
                                                  i18n("Import a saved configuration file"), QStringLiteral("document-import"),
