@@ -20,6 +20,7 @@
 
 #include "networkmodel.h"
 #include "networkmodelitem.h"
+#include "configuration.h"
 #include "debug.h"
 #include "uiutils.h"
 
@@ -168,6 +169,9 @@ void NetworkModel::initialize()
 
     // Initialize existing devices
     for (const NetworkManager::Device::Ptr &dev : NetworkManager::networkInterfaces()) {
+        if (!dev->managed()) {
+            continue;
+        }
         addDevice(dev);
     }
 
@@ -278,7 +282,6 @@ void NetworkModel::addActiveConnection(const NetworkManager::ActiveConnection::P
         addConnection(connection);
     }
 
-    beginResetModel();
     for (NetworkModelItem *item : m_list.returnItems(NetworkItemsList::NetworkItemsList::Uuid, connection->uuid())) {
         if (((device && device->uni() == item->devicePath()) || item->devicePath().isEmpty()) || item->type() == NetworkManager::ConnectionSettings::Vpn) {
             item->setActiveConnectionPath(activeConnection->path());
@@ -307,8 +310,8 @@ void NetworkModel::addActiveConnection(const NetworkManager::ActiveConnection::P
                 item->setTxBytes(deviceStatistics->txBytes());
             }
         }
+        updateItem(item);
     }
-    endResetModel();
 }
 
 void NetworkModel::addAvailableConnection(const QString &connection, const NetworkManager::Device::Ptr &device)
@@ -396,31 +399,33 @@ void NetworkModel::addConnection(const NetworkManager::Connection::Ptr &connecti
     }
 
     // Check whether the connection is already in the model to avoid duplicates, but this shouldn't happen
-    if (!m_list.contains(NetworkItemsList::Connection, connection->path())) {
-        NetworkModelItem *item = new NetworkModelItem();
-        item->setConnectionPath(connection->path());
-        item->setName(settings->id());
-        item->setTimestamp(settings->timestamp());
-        item->setType(settings->connectionType());
-        item->setUuid(settings->uuid());
-        item->setSlave(settings->isSlave());
-
-        if (item->type() == NetworkManager::ConnectionSettings::Vpn) {
-            item->setVpnType(vpnSetting->serviceType().section('.', -1));
-        } else if (item->type() == NetworkManager::ConnectionSettings::Wireless) {
-            item->setMode(wirelessSetting->mode());
-            item->setSecurityType(NetworkManager::securityTypeFromConnectionSetting(settings));
-            item->setSsid(QString::fromUtf8(wirelessSetting->ssid()));
-        }
-
-        item->invalidateDetails();
-
-        const int index = m_list.count();
-        beginInsertRows(QModelIndex(), index, index);
-        m_list.insertItem(item);
-        endInsertRows();
-        qCDebug(PLASMA_NM) << "New connection " << item->name() << " added";
+    if (m_list.contains(NetworkItemsList::Connection, connection->path())) {
+        return;
     }
+
+    NetworkModelItem *item = new NetworkModelItem();
+    item->setConnectionPath(connection->path());
+    item->setName(settings->id());
+    item->setTimestamp(settings->timestamp());
+    item->setType(settings->connectionType());
+    item->setUuid(settings->uuid());
+    item->setSlave(settings->isSlave());
+
+    if (item->type() == NetworkManager::ConnectionSettings::Vpn) {
+        item->setVpnType(vpnSetting->serviceType().section('.', -1));
+    } else if (item->type() == NetworkManager::ConnectionSettings::Wireless) {
+        item->setMode(wirelessSetting->mode());
+        item->setSecurityType(NetworkManager::securityTypeFromConnectionSetting(settings));
+        item->setSsid(QString::fromUtf8(wirelessSetting->ssid()));
+    }
+
+    item->invalidateDetails();
+
+    const int index = m_list.count();
+    beginInsertRows(QModelIndex(), index, index);
+    m_list.insertItem(item);
+    endInsertRows();
+    qCDebug(PLASMA_NM) << "New connection " << item->name() << " added";
 }
 
 void NetworkModel::addDevice(const NetworkManager::Device::Ptr &device)
@@ -443,6 +448,16 @@ void NetworkModel::addWirelessNetwork(const NetworkManager::WirelessNetwork::Ptr
 {
     initializeSignals(network);
 
+    // Avoid duplicating entries in the model
+    if (!Configuration::hotspotConnectionPath().isEmpty()) {
+        NetworkManager::ActiveConnection::Ptr activeConnection = NetworkManager::findActiveConnection(Configuration::hotspotConnectionPath());
+
+        // If we are trying to add an AP which is the one created by our hotspot, then we can skip this and don't add it twice
+        if (activeConnection && activeConnection->specificObject() == network->referenceAccessPoint()->uni()) {
+            return;
+        }
+    }
+
     // BUG: 386342
     // When creating a new hidden wireless network and attempting to connect to it, NM then later reports that AccessPoint appeared, but
     // it doesn't know its SSID from some reason, this also makes Wireless device to advertise a new available connection, which we later
@@ -450,18 +465,19 @@ void NetworkModel::addWirelessNetwork(const NetworkManager::WirelessNetwork::Ptr
     // AccessPoint appeared signal, this time we know SSID, but we don't attempt any merging, because it's usually the other way around, thus
     // we need to attempt to merge it here with a connection we guess it's related to this new AP
     for (NetworkModelItem *item : m_list.returnItems(NetworkItemsList::Type, NetworkManager::ConnectionSettings::Wireless)) {
-        if (item->itemType() == NetworkModelItem::AvailableConnection) {
-            NetworkManager::ConnectionSettings::Ptr connectionSettings = NetworkManager::findConnection(item->connectionPath())->settings();
-            if (connectionSettings && connectionSettings->connectionType() == NetworkManager::ConnectionSettings::Wireless) {
-                NetworkManager::WirelessSetting::Ptr wirelessSetting = connectionSettings->setting(NetworkManager::Setting::Wireless).dynamicCast<NetworkManager::WirelessSetting>();
-                if (QString::fromUtf8(wirelessSetting->ssid()) == network->ssid()) {
-                    const QString bssid =  NetworkManager::macAddressAsString(wirelessSetting->bssid());
-                    const QString restrictedHw = NetworkManager::macAddressAsString(wirelessSetting->macAddress());
-                    if ((bssid.isEmpty() || bssid == network->referenceAccessPoint()->hardwareAddress()) &&
-                        (restrictedHw.isEmpty() || restrictedHw == device->hardwareAddress())) {
-                        updateFromWirelessNetwork(item, network, device);
-                        return;
-                    }
+        if (item->itemType() != NetworkModelItem::AvailableConnection)
+            continue;
+
+        NetworkManager::ConnectionSettings::Ptr connectionSettings = NetworkManager::findConnection(item->connectionPath())->settings();
+        if (connectionSettings && connectionSettings->connectionType() == NetworkManager::ConnectionSettings::Wireless) {
+            NetworkManager::WirelessSetting::Ptr wirelessSetting = connectionSettings->setting(NetworkManager::Setting::Wireless).dynamicCast<NetworkManager::WirelessSetting>();
+            if (QString::fromUtf8(wirelessSetting->ssid()) == network->ssid()) {
+                const QString bssid =  NetworkManager::macAddressAsString(wirelessSetting->bssid());
+                const QString restrictedHw = NetworkManager::macAddressAsString(wirelessSetting->macAddress());
+                if ((bssid.isEmpty() || bssid == network->referenceAccessPoint()->hardwareAddress()) &&
+                    (restrictedHw.isEmpty() || restrictedHw == device->hardwareAddress())) {
+                    updateFromWirelessNetwork(item, network, device);
+                    return;
                 }
             }
         }
@@ -555,20 +571,23 @@ void NetworkModel::updateItem(NetworkModelItem*item)
     if (row >= 0) {
         item->invalidateDetails();
         QModelIndex index = createIndex(row, 0);
-        Q_EMIT dataChanged(index, index);
+        Q_EMIT dataChanged(index, index, item->changedRoles());
+        item->clearChangedRoles();
     }
 }
 
 void NetworkModel::accessPointSignalStrengthChanged(int signal)
 {
     NetworkManager::AccessPoint *apPtr = qobject_cast<NetworkManager::AccessPoint*>(sender());
-    if (apPtr) {
-        for (NetworkModelItem *item : m_list.returnItems(NetworkItemsList::Ssid, apPtr->ssid())) {
-            if (item->specificPath() == apPtr->uni()) {
-                item->setSignal(signal);
-                updateItem(item);
-                qCDebug(PLASMA_NM) << "AccessPoint " << item->name() << ": signal changed to " << item->signal();
-            }
+    if (!apPtr) {
+        return;
+    }
+
+    for (NetworkModelItem *item : m_list.returnItems(NetworkItemsList::Ssid, apPtr->ssid())) {
+        if (item->specificPath() == apPtr->uni()) {
+            item->setSignal(signal);
+            updateItem(item);
+            qCDebug(PLASMA_NM) << "AccessPoint " << item->name() << ": signal changed to " << item->signal();
         }
     }
 }
@@ -596,14 +615,15 @@ void NetworkModel::activeConnectionRemoved(const QString &activeConnection)
 void NetworkModel::activeConnectionStateChanged(NetworkManager::ActiveConnection::State state)
 {
     NetworkManager::ActiveConnection *activePtr = qobject_cast<NetworkManager::ActiveConnection*>(sender());
-    if (activePtr) {
-        beginResetModel();
-        for (NetworkModelItem *item : m_list.returnItems(NetworkItemsList::ActiveConnection, activePtr->path())) {
-            item->setConnectionState(state);
-            item->invalidateDetails();
-            qCDebug(PLASMA_NM) << "Item " << item->name() << ": active connection changed to " << item->connectionState();
-        }
-        endResetModel();
+
+    if (!activePtr) {
+        return;
+    }
+
+    for (NetworkModelItem *item : m_list.returnItems(NetworkItemsList::ActiveConnection, activePtr->path())) {
+        item->setConnectionState(state);
+        updateItem(item);
+        qCDebug(PLASMA_NM) << "Item " << item->name() << ": active connection changed to " << item->connectionState();
     }
 }
 
@@ -612,33 +632,35 @@ void NetworkModel::activeVpnConnectionStateChanged(NetworkManager::VpnConnection
     Q_UNUSED(reason)
     NetworkManager::ActiveConnection *activePtr = qobject_cast<NetworkManager::ActiveConnection*>(sender());
 
-    if (activePtr) {
-        for (NetworkModelItem *item : m_list.returnItems(NetworkItemsList::ActiveConnection, activePtr->path())) {
-            if (state == NetworkManager::VpnConnection::Prepare ||
-                state == NetworkManager::VpnConnection::NeedAuth ||
-                state == NetworkManager::VpnConnection::Connecting ||
-                state == NetworkManager::VpnConnection::GettingIpConfig) {
-                item->setConnectionState(NetworkManager::ActiveConnection::Activating);
-            } else if (state == NetworkManager::VpnConnection::Activated) {
-                item->setConnectionState(NetworkManager::ActiveConnection::Activated);
-            } else {
-                item->setConnectionState(NetworkManager::ActiveConnection::Deactivated);
-            }
-            item->setVpnState(state);
-            updateItem(item);
-            qCDebug(PLASMA_NM) << "Item " << item->name() << ": active connection changed to " << item->connectionState();
+    if (!activePtr) {
+        return;
+    }
+
+    for (NetworkModelItem *item : m_list.returnItems(NetworkItemsList::ActiveConnection, activePtr->path())) {
+        if (state == NetworkManager::VpnConnection::Prepare ||
+            state == NetworkManager::VpnConnection::NeedAuth ||
+            state == NetworkManager::VpnConnection::Connecting ||
+            state == NetworkManager::VpnConnection::GettingIpConfig) {
+            item->setConnectionState(NetworkManager::ActiveConnection::Activating);
+        } else if (state == NetworkManager::VpnConnection::Activated) {
+            item->setConnectionState(NetworkManager::ActiveConnection::Activated);
+        } else {
+            item->setConnectionState(NetworkManager::ActiveConnection::Deactivated);
         }
+        item->setVpnState(state);
+        updateItem(item);
+        qCDebug(PLASMA_NM) << "Item " << item->name() << ": active connection changed to " << item->connectionState();
     }
 }
 
 void NetworkModel::availableConnectionAppeared(const QString &connection)
 {
     NetworkManager::Device::Ptr device = NetworkManager::findNetworkInterface(qobject_cast<NetworkManager::Device*>(sender())->uni());
-    if (device) {
-        beginResetModel();
-        addAvailableConnection(connection, device);
-        endResetModel();
+    if (!device) {
+        return;
     }
+
+    addAvailableConnection(connection, device);
 }
 
 void NetworkModel::availableConnectionDisappeared(const QString &connection)
@@ -762,27 +784,29 @@ void NetworkModel::connectionRemoved(const QString &connection)
 void NetworkModel::connectionUpdated()
 {
     NetworkManager::Connection *connectionPtr = qobject_cast<NetworkManager::Connection*>(sender());
-    if (connectionPtr) {
-        NetworkManager::ConnectionSettings::Ptr settings = connectionPtr->settings();
-        for (NetworkModelItem *item : m_list.returnItems(NetworkItemsList::Connection, connectionPtr->path())) {
-            item->setConnectionPath(connectionPtr->path());
-            item->setName(settings->id());
-            item->setTimestamp(settings->timestamp());
-            item->setType(settings->connectionType());
-            item->setUuid(settings->uuid());
+    if (!connectionPtr) {
+        return;
+    }
 
-            if (item->type() == NetworkManager::ConnectionSettings::Wireless) {
-                NetworkManager::WirelessSetting::Ptr wirelessSetting;
-                wirelessSetting = settings->setting(NetworkManager::Setting::Wireless).dynamicCast<NetworkManager::WirelessSetting>();
-                item->setMode(wirelessSetting->mode());
-                item->setSecurityType(NetworkManager::securityTypeFromConnectionSetting(settings));
-                item->setSsid(QString::fromUtf8(wirelessSetting->ssid()));
-                // TODO check whether BSSID has changed and update the wireless info
-            }
+    NetworkManager::ConnectionSettings::Ptr settings = connectionPtr->settings();
+    for (NetworkModelItem *item : m_list.returnItems(NetworkItemsList::Connection, connectionPtr->path())) {
+        item->setConnectionPath(connectionPtr->path());
+        item->setName(settings->id());
+        item->setTimestamp(settings->timestamp());
+        item->setType(settings->connectionType());
+        item->setUuid(settings->uuid());
 
-            updateItem(item);
-            qCDebug(PLASMA_NM) << "Item " << item->name() << ": connection updated";
+        if (item->type() == NetworkManager::ConnectionSettings::Wireless) {
+            NetworkManager::WirelessSetting::Ptr wirelessSetting;
+            wirelessSetting = settings->setting(NetworkManager::Setting::Wireless).dynamicCast<NetworkManager::WirelessSetting>();
+            item->setMode(wirelessSetting->mode());
+            item->setSecurityType(NetworkManager::securityTypeFromConnectionSetting(settings));
+            item->setSsid(QString::fromUtf8(wirelessSetting->ssid()));
+            // TODO check whether BSSID has changed and update the wireless info
         }
+
+        updateItem(item);
+        qCDebug(PLASMA_NM) << "Item " << item->name() << ": connection updated";
     }
 }
 
@@ -809,14 +833,14 @@ void NetworkModel::deviceStateChanged(NetworkManager::Device::State state, Netwo
 
     NetworkManager::Device::Ptr device = NetworkManager::findNetworkInterface(qobject_cast<NetworkManager::Device*>(sender())->uni());
 
-    if (device) {
-        beginResetModel();
-        for (NetworkModelItem *item : m_list.returnItems(NetworkItemsList::Device, device->uni())) {
-            item->setDeviceState(state);
-            item->invalidateDetails();
+    if (!device) {
+        return;
+    }
+
+    for (NetworkModelItem *item : m_list.returnItems(NetworkItemsList::Device, device->uni())) {
+        item->setDeviceState(state);
+        updateItem(item);
 //             qCDebug(PLASMA_NM) << "Item " << item->name() << ": device state changed to " << item->deviceState();
-        }
-        endResetModel();
     }
 }
 
@@ -825,22 +849,31 @@ void NetworkModel::gsmNetworkAccessTechnologiesChanged(QFlags<MMModemAccessTechn
 {
     Q_UNUSED(accessTechnologies);
     ModemManager::Modem *gsmNetwork = qobject_cast<ModemManager::Modem*>(sender());
-    if (gsmNetwork) {
-        for (const NetworkManager::Device::Ptr &dev : NetworkManager::networkInterfaces()) {
-            if (dev->type() == NetworkManager::Device::Modem) {
-                ModemManager::ModemDevice::Ptr modem = ModemManager::findModemDevice(dev->udi());
-                if (modem) {
-                    if (modem->hasInterface(ModemManager::ModemDevice::ModemInterface)) {
-                        ModemManager::Modem::Ptr modemNetwork = modem->interface(ModemManager::ModemDevice::ModemInterface).objectCast<ModemManager::Modem>();
-                        if (modemNetwork && modemNetwork->device() == gsmNetwork->device()) {
-                            // TODO store access technology internally?
-                            for (NetworkModelItem *item : m_list.returnItems(NetworkItemsList::Device, dev->uni())) {
-                                updateItem(item);
-                            }
-                        }
-                    }
-                }
-            }
+    if (!gsmNetwork)
+        return;
+
+    for (const NetworkManager::Device::Ptr &dev : NetworkManager::networkInterfaces()) {
+        if (dev->type() != NetworkManager::Device::Modem) {
+            continue;
+        }
+
+        ModemManager::ModemDevice::Ptr modem = ModemManager::findModemDevice(dev->udi());
+        if (!modem) {
+            continue;
+        }
+
+        if (!modem->hasInterface(ModemManager::ModemDevice::ModemInterface)) {
+            continue;
+        }
+
+        ModemManager::Modem::Ptr modemNetwork = modem->interface(ModemManager::ModemDevice::ModemInterface).objectCast<ModemManager::Modem>();
+        if (!modemNetwork || modemNetwork->device() != gsmNetwork->device()) {
+            continue;
+        }
+
+        // TODO store access technology internally?
+        for (NetworkModelItem *item : m_list.returnItems(NetworkItemsList::Device, dev->uni())) {
+            updateItem(item);
         }
     }
 }
@@ -848,21 +881,30 @@ void NetworkModel::gsmNetworkAccessTechnologiesChanged(QFlags<MMModemAccessTechn
 void NetworkModel::gsmNetworkCurrentModesChanged()
 {
     ModemManager::Modem *gsmNetwork = qobject_cast<ModemManager::Modem*>(sender());
-    if (gsmNetwork) {
-        for (const NetworkManager::Device::Ptr &dev : NetworkManager::networkInterfaces()) {
-            if (dev->type() == NetworkManager::Device::Modem) {
-                ModemManager::ModemDevice::Ptr modem = ModemManager::findModemDevice(dev->udi());
-                if (modem) {
-                    if (modem->hasInterface(ModemManager::ModemDevice::ModemInterface)) {
-                        ModemManager::Modem::Ptr modemNetwork = modem->interface(ModemManager::ModemDevice::ModemInterface).objectCast<ModemManager::Modem>();
-                        if (modemNetwork && modemNetwork->device() == gsmNetwork->device()) {
-                            for (NetworkModelItem *item : m_list.returnItems(NetworkItemsList::Device, dev->uni())) {
-                                updateItem(item);
-                            }
-                        }
-                    }
-                }
-            }
+    if (!gsmNetwork) {
+        return;
+    }
+
+    for (const NetworkManager::Device::Ptr &dev : NetworkManager::networkInterfaces()) {
+        if (dev->type() != NetworkManager::Device::Modem)
+            continue;
+
+        ModemManager::ModemDevice::Ptr modem = ModemManager::findModemDevice(dev->udi());
+        if (!modem) {
+            continue;
+        }
+
+        if (!modem->hasInterface(ModemManager::ModemDevice::ModemInterface)) {
+            continue;
+        }
+
+        ModemManager::Modem::Ptr modemNetwork = modem->interface(ModemManager::ModemDevice::ModemInterface).objectCast<ModemManager::Modem>();
+        if (!modemNetwork || modemNetwork->device() != gsmNetwork->device()) {
+            continue;
+        }
+
+        for (NetworkModelItem *item : m_list.returnItems(NetworkItemsList::Device, dev->uni())) {
+            updateItem(item);
         }
     }
 }
@@ -870,22 +912,32 @@ void NetworkModel::gsmNetworkCurrentModesChanged()
 void NetworkModel::gsmNetworkSignalQualityChanged(const ModemManager::SignalQualityPair &signalQuality)
 {
     ModemManager::Modem *gsmNetwork = qobject_cast<ModemManager::Modem*>(sender());
-    if (gsmNetwork) {
-        for (const NetworkManager::Device::Ptr &dev : NetworkManager::networkInterfaces()) {
-            if (dev->type() == NetworkManager::Device::Modem) {
-                ModemManager::ModemDevice::Ptr modem = ModemManager::findModemDevice(dev->udi());
-                if (modem) {
-                    if (modem->hasInterface(ModemManager::ModemDevice::ModemInterface)) {
-                        ModemManager::Modem::Ptr modemNetwork = modem->interface(ModemManager::ModemDevice::ModemInterface).objectCast<ModemManager::Modem>();
-                        if (modemNetwork && modemNetwork->device() == gsmNetwork->device()) {
-                            for (NetworkModelItem *item : m_list.returnItems(NetworkItemsList::Device, dev->uni())) {
-                                item->setSignal(signalQuality.signal);
-                                updateItem(item);
-                            }
-                        }
-                    }
-                }
-            }
+    if (!gsmNetwork) {
+        return;
+    }
+
+    for (const NetworkManager::Device::Ptr &dev : NetworkManager::networkInterfaces()) {
+        if (dev->type() != NetworkManager::Device::Modem) {
+            continue;
+        }
+
+        ModemManager::ModemDevice::Ptr modem = ModemManager::findModemDevice(dev->udi());
+        if (!modem) {
+            continue;
+        }
+
+        if (!modem->hasInterface(ModemManager::ModemDevice::ModemInterface)) {
+            continue;
+        }
+
+        ModemManager::Modem::Ptr modemNetwork = modem->interface(ModemManager::ModemDevice::ModemInterface).objectCast<ModemManager::Modem>();
+        if (!modemNetwork || modemNetwork->device() != gsmNetwork->device()) {
+            continue;
+        }
+
+        for (NetworkModelItem *item : m_list.returnItems(NetworkItemsList::Device, dev->uni())) {
+            item->setSignal(signalQuality.signal);
+            updateItem(item);
         }
     }
 }
@@ -896,24 +948,28 @@ void NetworkModel::ipConfigChanged()
 {
    NetworkManager::Device::Ptr device = NetworkManager::findNetworkInterface(qobject_cast<NetworkManager::Device*>(sender())->uni());
 
-    if (device) {
-        for (NetworkModelItem *item : m_list.returnItems(NetworkItemsList::Device, device->uni())) {
-            updateItem(item);
+    if (!device) {
+        return;
+    }
+
+    for (NetworkModelItem *item : m_list.returnItems(NetworkItemsList::Device, device->uni())) {
+        updateItem(item);
 //            qCDebug(PLASMA_NM) << "Item " << item->name() << ": device ipconfig changed";
-        }
     }
 }
 
 void NetworkModel::ipInterfaceChanged()
 {
     NetworkManager::Device *device = qobject_cast<NetworkManager::Device*>(sender());
-    if (device) {
-        for (NetworkModelItem *item : m_list.returnItems(NetworkItemsList::Device, device->uni())) {
-            if (device->ipInterfaceName().isEmpty()) {
-                item->setDeviceName(device->interfaceName());
-            } else {
-                item->setDeviceName(device->ipInterfaceName());
-            }
+    if (!device) {
+        return;
+    }
+
+    for (NetworkModelItem *item : m_list.returnItems(NetworkItemsList::Device, device->uni())) {
+        if (device->ipInterfaceName().isEmpty()) {
+            item->setDeviceName(device->interfaceName());
+        } else {
+            item->setDeviceName(device->ipInterfaceName());
         }
     }
 }
@@ -942,29 +998,31 @@ void NetworkModel::wirelessNetworkAppeared(const QString &ssid)
 void NetworkModel::wirelessNetworkDisappeared(const QString &ssid)
 {
     NetworkManager::Device::Ptr device = NetworkManager::findNetworkInterface(qobject_cast<NetworkManager::Device*>(sender())->uni());
-    if (device) {
-        for (NetworkModelItem *item : m_list.returnItems(NetworkItemsList::Ssid, ssid, device->uni())) {
-            // Remove the entire item, because it's only AP or it's a duplicated available connection
-            if (item->itemType() == NetworkModelItem::AvailableAccessPoint || item->duplicate()) {
-                const int row = m_list.indexOf(item);
-                if (row >= 0) {
-                    qCDebug(PLASMA_NM) << "Wireless network " << item->name() << " removed completely";
-                    beginRemoveRows(QModelIndex(), row, row);
-                    m_list.removeItem(item);
-                    item->deleteLater();
-                    endRemoveRows();
-                }
-            // Remove only AP and device from the item and leave it as an unavailable connection
-            } else {
-                if (item->mode() == NetworkManager::WirelessSetting::Infrastructure) {
-                    item->setDeviceName(QString());
-                    item->setDevicePath(QString());
-                    item->setSpecificPath(QString());
-                }
-                item->setSignal(0);
-                updateItem(item);
-                qCDebug(PLASMA_NM) << "Item " << item->name() << ": wireless network removed";
+    if (!device) {
+        return;
+    }
+
+    for (NetworkModelItem *item : m_list.returnItems(NetworkItemsList::Ssid, ssid, device->uni())) {
+        // Remove the entire item, because it's only AP or it's a duplicated available connection
+        if (item->itemType() == NetworkModelItem::AvailableAccessPoint || item->duplicate()) {
+            const int row = m_list.indexOf(item);
+            if (row >= 0) {
+                qCDebug(PLASMA_NM) << "Wireless network " << item->name() << " removed completely";
+                beginRemoveRows(QModelIndex(), row, row);
+                m_list.removeItem(item);
+                item->deleteLater();
+                endRemoveRows();
             }
+        // Remove only AP and device from the item and leave it as an unavailable connection
+        } else {
+            if (item->mode() == NetworkManager::WirelessSetting::Infrastructure) {
+                item->setDeviceName(QString());
+                item->setDevicePath(QString());
+                item->setSpecificPath(QString());
+            }
+            item->setSignal(0);
+            updateItem(item);
+            qCDebug(PLASMA_NM) << "Item " << item->name() << ": wireless network removed";
         }
     }
 }
@@ -973,18 +1031,24 @@ void NetworkModel::wirelessNetworkReferenceApChanged(const QString &accessPoint)
 {
     NetworkManager::WirelessNetwork *networkPtr = qobject_cast<NetworkManager::WirelessNetwork*>(sender());
 
-    if (networkPtr) {
-        for (NetworkModelItem *item : m_list.returnItems(NetworkItemsList::Ssid, networkPtr->ssid(), networkPtr->device())) {
-            NetworkManager::Connection::Ptr connection = NetworkManager::findConnection(item->connectionPath());
-            if (connection) {
-                NetworkManager::WirelessSetting::Ptr wirelessSetting = connection->settings()->setting(NetworkManager::Setting::Wireless).staticCast<NetworkManager::WirelessSetting>();
-                if (wirelessSetting) {
-                    if (wirelessSetting->bssid().isEmpty()) {
-                        item->setSpecificPath(accessPoint);
-                        updateItem(item);
-                    }
-                }
-            }
+    if (!networkPtr) {
+        return;
+    }
+
+    for (NetworkModelItem *item : m_list.returnItems(NetworkItemsList::Ssid, networkPtr->ssid(), networkPtr->device())) {
+        NetworkManager::Connection::Ptr connection = NetworkManager::findConnection(item->connectionPath());
+        if (!connection) {
+            continue;
+        }
+
+        NetworkManager::WirelessSetting::Ptr wirelessSetting = connection->settings()->setting(NetworkManager::Setting::Wireless).staticCast<NetworkManager::WirelessSetting>();
+        if (!wirelessSetting) {
+            continue;
+        }
+
+        if (wirelessSetting->bssid().isEmpty()) {
+            item->setSpecificPath(accessPoint);
+            updateItem(item);
         }
     }
 }
@@ -992,13 +1056,15 @@ void NetworkModel::wirelessNetworkReferenceApChanged(const QString &accessPoint)
 void NetworkModel::wirelessNetworkSignalChanged(int signal)
 {
     NetworkManager::WirelessNetwork *networkPtr = qobject_cast<NetworkManager::WirelessNetwork*>(sender());
-    if (networkPtr) {
-        for (NetworkModelItem *item : m_list.returnItems(NetworkItemsList::Ssid, networkPtr->ssid(), networkPtr->device())) {
-            if (item->specificPath() == networkPtr->referenceAccessPoint()->uni()) {
-                item->setSignal(signal);
-                updateItem(item);
+    if (!networkPtr) {
+        return;
+    }
+
+    for (NetworkModelItem *item : m_list.returnItems(NetworkItemsList::Ssid, networkPtr->ssid(), networkPtr->device())) {
+        if (item->specificPath() == networkPtr->referenceAccessPoint()->uni()) {
+            item->setSignal(signal);
+            updateItem(item);
 //              qCDebug(PLASMA_NM) << "Wireless network " << item->name() << ": signal changed to " << item->signal();
-            }
         }
     }
 }
