@@ -484,7 +484,10 @@ qulonglong NetworkModelItem::rxBytes() const
 
 void NetworkModelItem::setRxBytes(qulonglong bytes)
 {
-    m_rxBytes = bytes;
+    if (m_rxBytes != bytes) {
+        m_rxBytes = bytes;
+        m_changedRoles << NetworkModel::RxBytesRole;
+    }
 }
 
 qulonglong NetworkModelItem::txBytes() const
@@ -494,7 +497,10 @@ qulonglong NetworkModelItem::txBytes() const
 
 void NetworkModelItem::setTxBytes(qulonglong bytes)
 {
-    m_txBytes = bytes;
+    if (m_txBytes != bytes) {
+        m_txBytes = bytes;
+        m_changedRoles << NetworkModel::TxBytesRole;
+    }
 }
 
 bool NetworkModelItem::operator==(const NetworkModelItem *item) const
@@ -515,6 +521,7 @@ bool NetworkModelItem::operator==(const NetworkModelItem *item) const
 void NetworkModelItem::invalidateDetails()
 {
     m_detailsValid = false;
+    m_changedRoles << NetworkModel::ConnectionDetailsRole;
 }
 
 void NetworkModelItem::updateDetails() const
@@ -528,7 +535,7 @@ void NetworkModelItem::updateDetails() const
 
     NetworkManager::Device::Ptr device = NetworkManager::findNetworkInterface(m_devicePath);
 
-    // Get IPv[46]Address
+    // Get IPv[46]Address and related nameservers + IPv4 default gateway
     if (device && device->ipV4Config().isValid() && m_connectionState == NetworkManager::ActiveConnection::Activated) {
         if (!device->ipV4Config().addresses().isEmpty()) {
             QHostAddress addr = device->ipV4Config().addresses().first().ip();
@@ -536,6 +543,18 @@ void NetworkModelItem::updateDetails() const
                 m_details << i18n("IPv4 Address") << addr.toString();
             }
         }
+        if (!device->ipV4Config().gateway().isEmpty()) {
+            QString addr = device->ipV4Config().gateway();
+            if (!addr.isNull()) {
+                m_details << i18n("IPv4 Default Gateway") << addr;
+            }
+        }
+        if (!device->ipV4Config().nameservers().isEmpty()) {
+            QHostAddress addr = device->ipV4Config().nameservers().first();
+            if (!addr.isNull()) {
+                m_details << i18n("IPv4 Nameserver") << addr.toString();
+            }
+        }
     }
 
     if (device && device->ipV6Config().isValid() && m_connectionState == NetworkManager::ActiveConnection::Activated) {
@@ -545,6 +564,12 @@ void NetworkModelItem::updateDetails() const
                 m_details << i18n("IPv6 Address") << addr.toString();
             }
         }
+        if (!device->ipV6Config().nameservers().isEmpty()) {
+            QHostAddress addr = device->ipV6Config().nameservers().first();
+            if (!addr.isNull()) {
+                m_details << i18n("IPv6 Nameserver") << addr.toString();
+            }
+        }
     }
     if (m_type == NetworkManager::ConnectionSettings::Wired) {
         NetworkManager::WiredDevice::Ptr wiredDevice = device.objectCast<NetworkManager::WiredDevice>();
